@@ -83,6 +83,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--with-dtrace' "
                 "'--with-lto' '--with-ssl-default-suites=openssl' "
+                "'--with-builtin-hashlib-hashes=blake2' "
                 "'--without-static-libpython' "
                 "'--with-wheel-pkg-dir=/usr/share/python3-wheels' "
                 "'--with-valgrind' '--without-ensurepip' "
@@ -806,21 +807,21 @@ build_time_vars = {'ABIFLAGS': '',
                    '_json  _lsprof  _opcode  _pickle  _queue  _random  '
                    '_struct  _xxsubinterpreters  _xxinterpchannels  _zoneinfo  '
                    'audioop  math  cmath  _statistics  _datetime  _decimal  '
-                   'binascii  _bz2  _lzma  zlib  _dbm  _gdbm  readline  _md5  '
-                   '_sha1  _sha2  _sha3  _blake2  pyexpat  _elementtree  '
-                   '_codecs_cn  _codecs_hk  _codecs_iso2022  _codecs_jp  '
-                   '_codecs_kr  _codecs_tw  _multibytecodec  unicodedata  '
-                   '_crypt  fcntl  grp  mmap  ossaudiodev  _posixsubprocess  '
-                   'resource  select  _socket  spwd  syslog  termios  '
-                   '_posixshmem  _multiprocessing  _ctypes  _curses  '
-                   '_curses_panel  _sqlite3  _ssl  _hashlib  _uuid  _tkinter  '
-                   'xxsubtype  _xxtestfuzz  _testbuffer  _testinternalcapi  '
-                   '_testcapi  _testclinic  _testimportmultiple  '
-                   '_testmultiphase  _testsinglephase  _ctypes_test  '
-                   'xxlimited  xxlimited_35  atexit  faulthandler  posix  '
-                   '_signal  _tracemalloc  _codecs  _collections  errno  _io  '
-                   'itertools  _sre  _thread  time  _typing  _weakref  _abc  '
-                   '_functools  _locale  _operator  _stat  _symtable  pwd',
+                   'binascii  _bz2  _lzma  zlib  _dbm  _gdbm  readline  '
+                   '_blake2  pyexpat  _elementtree  _codecs_cn  _codecs_hk  '
+                   '_codecs_iso2022  _codecs_jp  _codecs_kr  _codecs_tw  '
+                   '_multibytecodec  unicodedata  _crypt  fcntl  grp  mmap  '
+                   'ossaudiodev  _posixsubprocess  resource  select  _socket  '
+                   'spwd  syslog  termios  _posixshmem  _multiprocessing  '
+                   '_ctypes  _curses  _curses_panel  _sqlite3  _ssl  _hashlib  '
+                   '_uuid  _tkinter  xxsubtype  _xxtestfuzz  _testbuffer  '
+                   '_testinternalcapi  _testcapi  _testclinic  '
+                   '_testimportmultiple  _testmultiphase  _testsinglephase  '
+                   '_ctypes_test  xxlimited  xxlimited_35  atexit  '
+                   'faulthandler  posix  _signal  _tracemalloc  _codecs  '
+                   '_collections  errno  _io  itertools  _sre  _thread  time  '
+                   '_typing  _weakref  _abc  _functools  _locale  _operator  '
+                   '_stat  _symtable  pwd',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
@@ -840,17 +841,16 @@ build_time_vars = {'ABIFLAGS': '',
                     '_lsprof _opcode _pickle _queue _random _struct '
                     '_xxsubinterpreters _xxinterpchannels _zoneinfo audioop '
                     'math cmath _statistics _datetime _decimal binascii _bz2 '
-                    '_lzma zlib _dbm _gdbm readline _md5 _sha1 _sha2 _sha3 '
-                    '_blake2 pyexpat _elementtree _codecs_cn _codecs_hk '
-                    '_codecs_iso2022 _codecs_jp _codecs_kr _codecs_tw '
-                    '_multibytecodec unicodedata _crypt fcntl grp mmap '
-                    'ossaudiodev _posixsubprocess resource select _socket spwd '
-                    'syslog termios _posixshmem _multiprocessing _ctypes '
-                    '_curses _curses_panel _sqlite3 _ssl _hashlib _uuid '
-                    '_tkinter xxsubtype _xxtestfuzz _testbuffer '
-                    '_testinternalcapi _testcapi _testclinic '
-                    '_testimportmultiple _testmultiphase _testsinglephase '
-                    '_ctypes_test xxlimited xxlimited_35',
+                    '_lzma zlib _dbm _gdbm readline _blake2 pyexpat '
+                    '_elementtree _codecs_cn _codecs_hk _codecs_iso2022 '
+                    '_codecs_jp _codecs_kr _codecs_tw _multibytecodec '
+                    'unicodedata _crypt fcntl grp mmap ossaudiodev '
+                    '_posixsubprocess resource select _socket spwd syslog '
+                    'termios _posixshmem _multiprocessing _ctypes _curses '
+                    '_curses_panel _sqlite3 _ssl _hashlib _uuid _tkinter '
+                    'xxsubtype _xxtestfuzz _testbuffer _testinternalcapi '
+                    '_testcapi _testclinic _testimportmultiple _testmultiphase '
+                    '_testsinglephase _ctypes_test xxlimited xxlimited_35',
  'MODULE_ARRAY_STATE': 'yes',
  'MODULE_ATEXIT_LDFLAGS': '',
  'MODULE_AUDIOOP_LDFLAGS': '-lm',
@@ -923,7 +923,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s.c '
                         '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/blake2module.h '
                         '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h',
- 'MODULE__BLAKE2_LDFLAGS': '',
+ 'MODULE__BLAKE2_LDFLAGS': '-lssl -lcrypto',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
@@ -1008,13 +1008,10 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
-                       '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/internal '
-                       '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
  'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h \\ '
                      'Modules/_hacl/Hacl_Hash_MD5.h '
                      'Modules/_hacl/Hacl_Hash_MD5.c',
- 'MODULE__MD5_STATE': 'yes',
+ 'MODULE__MD5_STATE': 'disabled',
  'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
  'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_multiprocessing',
@@ -1029,23 +1026,17 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
-                        '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/internal '
-                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
  'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA1.h '
                       'Modules/_hacl/Hacl_Hash_SHA1.c',
- 'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA2_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
-                        '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/internal '
-                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA1_STATE': 'disabled',
  'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
                       '\\ Modules/_hacl/libHacl_Hash_SHA2.a',
- 'MODULE__SHA2_STATE': 'yes',
+ 'MODULE__SHA2_STATE': 'disabled',
  'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA3.h '
                       'Modules/_hacl/Hacl_Hash_SHA3.c',
- 'MODULE__SHA3_STATE': 'yes',
+ 'MODULE__SHA3_STATE': 'disabled',
  'MODULE__SIGNAL_LDFLAGS': '',
  'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/socketmodule.h '
                         '/builddir/build/BUILD/Python-3.12.2/Modules/addrinfo.h '
@@ -1142,7 +1133,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
                              '-fexceptions -fexceptions -fexceptions -O2 '
@@ -1369,10 +1360,6 @@ build_time_vars = {'ABIFLAGS': '',
                'Modules/_dbm.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/_gdbm.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/readline.cpython-312-powerpc64le-linux-gnu.so '
-               'Modules/_md5.cpython-312-powerpc64le-linux-gnu.so '
-               'Modules/_sha1.cpython-312-powerpc64le-linux-gnu.so '
-               'Modules/_sha2.cpython-312-powerpc64le-linux-gnu.so '
-               'Modules/_sha3.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/_blake2.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/pyexpat.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/_elementtree.cpython-312-powerpc64le-linux-gnu.so '
